function ent=enth1(ti,tf,cp)
% enth1 - Finds the enthalpy change for one compound over a
%         temperature range
% 
% enth1 finds the specific enthalpy change for one compound associated 
%       with any temperature change over which the specific heat is
%       valid (from ti to tf) 
%
% function ent=enth1(ti,tf,cp) 
% Arguments:
%      ti     the initial temperature
%      tf     the final temperature
%      cp     a row vector of constant that give the specific
%             heat as:   cp(1) + cp(2)*t +cp(3)*t^2 ...,
%
% The units required for ti and tf and the units of
%  	ent are set by the constants in cp.
% 
% See also enth2, enth3
% 
% Example: Use start301 to specify M&E properties for benzene
%          >>  enth1(300,400,cpv)
% OKB, revised help by TYLC & MAH
n=length(cp);
ent=0;
for i=1:n
   ent=ent+cp(i)*((tf^i)-ti^i)/i;
end
 
